This is a legacy function and is not used.
compute.covariance.from.distance(distance, r, type = "exp", ssm)A matrix. A symmetric matrix of distances between design points.
A number. The length parameter for the correlation function
(optional) Character. Specifies the correlation function. Default
behaviour is to use "exp" for a squared exponential correlation.
"Matern32" uses a Matern 3/2 correlation.
(obsolete) An SSM object. Used for the removed
"ssm" correlation function which tried to use the local smoothness
of the SSM to measure distances.