This function repeatedly fits the SSM to all but one held out point in turn and computes the prediction error at the held out point. These errors are collated into a vector indicating the Leave-One-Out error at each design point.
compute.residuals(ssm)An SSM object that has valid entries for the slots
response, K, and design_model_matrix.
A vector of Leave-One_Out errors.